serialize_dedup

Function serialize_dedup 

pub fn serialize_dedup<T, R, State, S>(
    value: &T,
    repr: R,
    state: &State,
    serializer: S,
) -> Result<S::Ok, S::Error>
where T: Dedup, R: SerializeState<State>, State: DedupSerializerState, S: Serializer,
Serialize value, deduplicating it if the state says so. repr is the serialized form of value, only used the first time we meet it.