pub struct DedupId(u32);Expand description
Identifies a deduplicated value amongst the values of its type within a single serialized output. Ids are allocated in the order in which we serialize the values.
Tuple Fields
0: u32Trait Implementations
impl Copy for DedupId
Sourceimpl<'de> Deserialize<'de> for DedupId
impl<'de> Deserialize<'de> for DedupId
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DedupId
impl StructuralPartialEq for DedupId