pub struct DedupSerializer {
ser: RefCell<TypeMap<SerializeTableMapper>>,
de: RefCell<TypeMap<DeserializeTableMapper>>,
}Expand description
Deduplicate the values of each type, in one table per type.
Fields
ser: RefCell<TypeMap<SerializeTableMapper>>de: RefCell<TypeMap<DeserializeTableMapper>>Trait Implementations
Sourceimpl DedupSerializerState for DedupSerializer
impl DedupSerializerState for DedupSerializer
Sourcefn record_serialized<T: Dedup>(
&self,
value: &T,
) -> Option<Result<DedupId, DedupId>>
fn record_serialized<T: Dedup>( &self, value: &T, ) -> Option<Result<DedupId, DedupId>>
Record that we’re serializing this value. Returns
None if we’re not deduplicating
values, Some(Ok(id)) the first time we meet a given value (it must then be serialized
in full), and Some(Err(id)) afterwards (only the id must be serialized).Sourcefn record_deserialized<T: Dedup>(&self, id: DedupId, value: T)
fn record_deserialized<T: Dedup>(&self, id: DedupId, value: T)
Record that we deserialized the value with this id.
Sourceimpl Default for DedupSerializer
impl Default for DedupSerializer
Sourcefn default() -> DedupSerializer
fn default() -> DedupSerializer
Returns the “default value” for a type. Read more